@@ -60,39 +60,63 @@ proc configureFilterGraph {} {
     destroy $w
   }
   
-  toplevel $w
+  win::createDialog $w
   wm title $w $::tr(ConfigureFilter)
   setWinLocation $w
   bind $w <F1> {helpWindow Graphs Filter}
-  frame $w.filter
+  ttk::labelframe $w.filternew -text "Config $::tr(Year) $::tr(Rating)"
   set col 0
   set row 0
   #Create input for each configurationvalue
   foreach { i n } { Year Year Elo Rating Moves moves} {
-    label $w.filter.label$i -text $::tr($n): -font font_Bold
-    grid $w.filter.label$i -row $row -column $col -sticky w
+    ttk::label $w.filternew.label$i -text $::tr($n): -font font_Bold
+    grid $w.filternew.label$i -row $row -column $col -sticky w
     incr col
     foreach {j k} { FilterMin "  " FilterMax " - " FilterStep "  Interval:"} {
-      label $w.filter.label$j$i -text $k
-      entry $w.filter.i$j$i -textvariable $j$i -justify right -width 5 -validate all -vcmd { regexp {^[0-9]{0,4}$} %P }
-      grid $w.filter.label$j$i -row $row -column $col -sticky w
+      ttk::label $w.filternew.label$j$i -text $k
+      ttk::entry $w.filternew.i$j$i -textvariable $j$i -justify right -width 5 -validate all -validatecommand { regexp {^[0-9]{0,4}$} %P }
+      grid $w.filternew.label$j$i -row $row -column $col -sticky w
       incr col
-      grid $w.filter.i$j$i -row $row -column $col -sticky w
+      grid $w.filternew.i$j$i -row $row -column $col -sticky w
       incr col
     }
     if { $i == "Elo" } {
-      checkbutton $w.filter.iEloGuess -text $::tr(FilterEstimate) -onvalue 1 -offvalue 0 -variable FilterGuessELO
-      grid $w.filter.iEloGuess -row $row -column $col -sticky w
-      #	  incr col
+      ttk::checkbutton $w.filternew.iEloGuess -text $::tr(FilterEstimate) -onvalue 1 -offvalue 0 -variable FilterGuessELO
+      grid $w.filternew.iEloGuess -row $row -column $col -sticky w -padx "5 0"
     }
     incr row
     set col 0
   }
-  
-  button $w.close -textvar ::tr(Close) -command {
+  if { [winfo exists .statsWin]} {
+      ttk::labelframe $w.filterold -text "Config StatYear StatElo OldYear OldElo"
+      foreach { i h v s } { Elo OprepStatBoth r* "+" Year OprepStatSince y* ".01.01" } {
+	  ttk::frame $w.filterold.old$i
+	  ttk::label $w.filterold.old$i.label -textvariable ::tr($h) -font font_Bold
+	  ttk::scrollbar $w.filterold.old$i.ybar -command "$w.filterold.old$i.list yview"
+	  listbox $w.filterold.old$i.list -yscrollcommand "$w.filterold.old$i.ybar set" \
+	      -height 7 -width 10 -selectmode multiple -exportselection 0
+	  pack $w.filterold.old$i.label -side top -anchor w
+	  pack $w.filterold.old$i.ybar -side right -fill y
+	  pack $w.filterold.old$i.list -side left -fill both -expand 1
+	  set j 0
+	  foreach y [lsort -decreasing [array names ::windows::stats::display $v]] {
+	      set value [string range $y 1 end]
+	      $w.filterold.old$i.list insert end "$value$s"
+	      if { $::windows::stats::display($y) } {
+	      $w.filterold.old$i.list selection set $j
+	      }
+	      incr j
+	  }
+      }
+      pack $w.filterold.oldElo -side left -expand 1 -in $w.filterold -fill both -padx "0 10"
+      pack $w.filterold.oldYear -side left -expand 1 -fill both -in $w.filterold
+  }
+
+  ttk::frame $w.buttons
+  ttk::button $w.buttons.close -textvar ::tr(Close) -command {
     checkConfigFilterGraph; ::tools::graphs::filter::Refresh
     ::tools::graphs::absfilter::Refresh; destroy .configFilterGraph  }
-  button $w.standard -textvar ::tr(Defaults) -command {
+  ttk::button $w.buttons.standard -textvar ::tr(Defaults) -command {
     set FilterMinElo 2100
     set FilterMaxElo 2800
     set FilterStepElo 100
@@ -104,14 +128,36 @@ proc configureFilterGraph {} {
     set FilterStepMoves 1
     set FilterGuessELO 1
   }
-  button $w.update -textvar ::tr(Update) -command { checkConfigFilterGraph
-    ::tools::graphs::absfilter::Refresh;
-    ::tools::graphs::filter::Refresh
+  if { [winfo exists .statsWin]} {
+     ttk::button $w.buttons.update -textvar ::tr(Update) -command { checkConfigFilterGraph
+	  set j 0
+	  foreach i [lsort -decreasing [array names ::windows::stats::display y*]] {
+	      set ::windows::stats::display($i) [.configFilterGraph.filterold.oldYear.list selection includes $j]
+	      incr j
+	  }
+	  set j 0
+	  foreach i [lsort -decreasing [array names ::windows::stats::display r*]] {
+	      set ::windows::stats::display($i) [.configFilterGraph.filterold.oldElo.list selection includes $j]
+	      incr j
+	  }
+	 ::tools::graphs::absfilter::Refresh;
+	 ::tools::graphs::filter::Refresh
+	 ::windows::stats::refresh_wnd
+     }
+  } else {
+     ttk::button $w.buttons.update -textvar ::tr(Update) -command { checkConfigFilterGraph
+	 ::tools::graphs::absfilter::Refresh;
+	 ::tools::graphs::filter::Refresh
+     }
   }
   
-  pack $w.filter
-  pack $w.close $w.update $w.standard -side right -padx 2 -pady 2
-  focus $w.filter.iFilterMinYear
+  pack $w.filternew -side top -fill x
+  if { [winfo exists .statsWin]} {
+      pack $w.filterold -side top -fill both -expand 1 -pady "10 0"
+  }
+  pack $w.buttons -anchor e
+  packdlgbuttons $w.buttons.close $w.buttons.update $w.buttons.standard
+  focus $w.filternew.iFilterMinYear
   bind $w <Configure> "recordWinSize $w"
 }
 
@@ -132,9 +178,9 @@ proc tools::graphs::filter::Open {} {
     set filterGraph 0
     return
   }
-  toplevel $w
+  win::createDialog $w 0
   menu $w.menu
-  $w configure -menu $w.menu
+  ::setMenu $w $w.menu
   $w.menu add cascade -label GraphFile -menu $w.menu.file
   configMenuText $w.menu 0 GraphFile $::language
   menu $w.menu.file
@@ -149,13 +195,11 @@ proc tools::graphs::filter::Open {} {
   set filterGraph 1
   bind $w <Destroy> {set filterGraph 0}
   
-  frame $w.b
-  pack $w.b -side bottom -fill x
-  label $w.b.status -width 1 -font font_Small -anchor w
-  frame $w.sep -height 2 -borderwidth 2 -relief sunken -background white
-  pack $w.sep -side bottom -fill x -pady 4
+  ttk::frame $w.b
+  pack $w.b -side top -fill x
+  ttk::label $w.b.status -width 1 -font font_Small -anchor w
   
-  canvas $w.c -width 600 -height 400
+  canvas $w.c -width 600 -height 400 -selectforeground [ttk::style lookup . -foreground] -background [ttk::style lookup . -background]
   $w.c create text 25 5 -tag title -justify center -width 1 \
       -font font_Small -anchor n
   $w.c create text 250 295 -tag type -justify center -width 1 \
@@ -178,15 +222,14 @@ proc tools::graphs::filter::Open {} {
   bind $w.c <$::MB3> ::tools::graphs::filter::Refresh
   
   foreach {name text} {decade Decade year Year elo Rating move moves} {
-    radiobutton $w.b.$name -padx 4 -pady 3 -text $::tr($text) \
+    ttk::radiobutton $w.b.$name -text $::tr($text) \
         -variable ::tools::graphs::filter::type -value $name \
         -command ::tools::graphs::filter::Refresh
     pack $w.b.$name -side left -padx 1 -pady 2
   }
-  button $w.b.setup -image tb_graph -command configureFilterGraph
-  dialogbutton $w.b.close -text $::tr(Close) -command "destroy $w"
+  ttk::button $w.b.setup -image tb_config -command configureFilterGraph
   pack $w.b.decade $w.b.elo -side left -padx 1 -pady 2
-  pack $w.b.close $w.b.setup -side right -padx 2 -pady 2
+  pack $w.b.setup -side right -pady 2
   pack $w.b.status -side left -padx 2 -pady 2 -fill x -expand yes
   
   ::tools::graphs::filter::Refresh
@@ -356,24 +399,208 @@ proc ::tools::graphs::filter::Refresh {} {
   update
 }
 
-#Klimmek: Invert white/black Score in Score graph
+#Invert white/black Score in Score graph, switches for display move time and adding time
 set ::tools::graphs::score::White 0
 set ::tools::graphs::score::Black 0
+set ::tools::graphs::score::ThinkTime 0
+set ::tools::graphs::score::Both 1
+set ::tools::graphs::score::TimeSum 1
 
-####################
-# Game score graph
+###########################
+# Game score and time graph
 
-proc ::tools::graphs::score::Refresh {} {
+# MoveTimeList
+#    Returns a Tcl list of the numeric times of each move, as found
+#    in the commment for each move.
+#    A time is a number with the format
+#        "%clk 00:00:00" or
+#        "%clkms 12345" (used by BabaChess) or
+#        "%emt 00:00:00" (used by pychess)
+#        "%emt 1.23" (used by Raptor)
+#    found somewhere in the comment of the move.
+proc MoveTimeList {color add} {
+    set movetimes   { }
+    set mainline { }
+    set base [sc_base current]
+    set gnum [sc_game number]
+    set game [sc_base getGame $base $gnum live]
+    set n [llength $game]
+    set movenr 0
+    for {set i 0} { $i < $n} { incr i } {
+	set RAVd [lindex [lindex $game $i] 0]
+	set RAVn [lindex [lindex $game $i] 1]
+	# only search in the mainline
+	if { $RAVd == 0 && $RAVn == 0} {
+	    # append comments for white
+	    if {  $color == "w" && [expr $movenr % 2] == 1 }  {
+		lappend mainline [lindex [lindex $game $i] 4] }
+	    # append comments for black
+	    if {  $color == "b" && [expr $movenr % 2] == 0 }  {
+		lappend mainline [lindex [lindex $game $i] 4] }
+	    incr movenr
+	}
+    }
+    set movenr 0
+    set offset 0.0
+    if {  $color == "w" } { set offset 0.5 }
+    set sum 0.0
+    for {set i 0} { $i < $n} { incr i } {
+	# only look for the first match, because normaly only one of these types should used in game
+	set comment [lindex $mainline $i]
+	set clkmsExp {.*?\[%clkms\s*(.*?)\s*\].*}
+	set clkms ""
+	regexp $clkmsExp $comment -> clkms
+	if { $clkms != "" } {
+	    scan $clkms "%f" sec
+	    if { [scan $clkms "%f" sec ] == 1 } {
+		# scale millisec to minutes
+		lappend movetimes [expr $movenr+$offset] [expr { $sec / 60000.0 }] }
+	} else {
+	    set clkExp {.*?\[%clk\s*(.*?)\s*\].*}
+	    set clock ""
+	    regexp $clkExp $comment -> clock
+	    if { $clock != "" } {
+		if { [scan $clock "%f:%f:%f" ho mi sec ] == 3 } {
+		    lappend movetimes [expr $movenr+$offset] [expr { $ho*60.0 + $mi + $sec/60}] }
+	    } else {
+		set emtExp {.*?\[%emt\s*(.*?)\s*\].*}
+		set emt ""
+		regexp $emtExp $comment -> emt
+		if { $emt != "" } {
+		    # emt could have 2 formats: 00:12:34 or 1.23
+		    set ok 0
+		    if { [regexp ":" $emt] } {
+			if { [scan $emt "%f:%f:%f" ho mi sec ] == 3 } { incr ok }
+		    } else {
+			set ho 0.0
+			set mi 0.0
+			if { [scan $emt "%f" sec ] == 1 } { incr ok }
+		    }
+		    if { $ok == 1 } {
+			set f [expr { $ho*3600.0 + $mi*60 + $sec}]
+			if { $add == 1 } {
+			    # add move times and scale to minutes
+			    set f [expr { $f/60.0 + $sum }]
+			    set sum $f
+			}
+			lappend movetimes [expr $movenr+$offset] $f
+		    }
+		}
+	    }
+	}
+	incr movenr
+    }
+    return $movetimes
+}
+
+# MoveScoreList
+#    Returns a Tcl list of the numeric move scores, as found
+#    in the commment for each move.
+#    A score is a number with the format
+#        "+0.23" or
+#        "-2.3" or
+#        ":M4", ":M-4", "+M4", "-M4" for announce Mate
+#    found somewhere in the comment of the move.
+#    The list returned should be read in pairs of values: the first is the
+#    move (0.0 = start, 0.5 after White's first move, 1.0 after Black's
+#    first move, etc) and the second is the value found.
+proc MoveScoreList { invw invb } {
+    set moveScores { }
+    set mainline { }
+    set base [sc_base current]
+    set gnum [sc_game number]
+    set game [sc_base getGame $base $gnum live]
+    set n [llength $game]
+    set movenr 0
+    for {set i 0} { $i < $n} { incr i } {
+	set RAVd [lindex [lindex $game $i] 0]
+	set RAVn [lindex [lindex $game $i] 1]
+	# only search in the mainline
+	if { $RAVd == 0 && $RAVn == 0} {
+	    lappend mainline [lindex [lindex $game $i] 4]
+	}
+    }
+    set movenr 0.0
+    set side 0
+    for {set i 1} { $i < $n} { incr i } {
+	set comment [lindex $mainline $i]
+	set evalExp {.*?\[%eval\s*(.*?)\s*\].*}
+	set eval ""
+	#little trick to check for valid score
+	set score -20.0
+	regexp $evalExp $comment -> eval
+	if { $eval != "" } { # check for [%eval 1.23]
+	    scan $eval "%f" score
+	    if { [scan $eval "%f" score ] == 1 } {
+		if { $score > 10 } { set score 9.9 }
+		if { $score < -10 } { set score -9.9 }
+	    } else {
+		# Mate found in %eval #N oder #-N
+		if { [string first "#" $eval] != -1 } {
+		    set score 9.9
+		    if { [string first "-" $eval] > 0 } { set score -9.9 }
+		}
+	    }
+	}
+	set foundIndex [string first ":M" $comment]
+	# check for Mate :M5 or :M-3
+	if { $foundIndex >= 0 } {
+	    if { [scan [string range $comment [expr $foundIndex+2] end] "%f" score] == 1 } {
+		# change Mate in x to +/-9.9
+		if { $score >= 1 } { set score 9.9 }
+		if { $score <= -1 } { set score -9.9 }
+	    }
+	} else {
+	    set f 1
+	    set foundIndex [string first "+M" $comment]
+	    if { $foundIndex < 0 } { set foundIndex [string first "-M" $comment]; set f -1 }
+	    # check for Mate +M5 or -M3 (Annotation from Arena GUI)
+	    if { $foundIndex >= 0 } {
+		if { [scan [string range $comment [expr $foundIndex+2] end] "%f" score] == 1 } {
+		    # change Mate in x to +/-9.9
+		    set score [expr $f * $score]
+		    if { $score >= 1 } { set score 9.9 }
+		    if { $score <= -1 } { set score -9.9 }
+		}
+	    } else {
+		# check for scores +1.23 or -1.23, find the first apperance in the comment
+		set foundIndex [string first "+" $comment]
+		if { $foundIndex < 0 } { set foundIndex [string first "-" $comment] }
+		if { $foundIndex >= 0 } {
+		    if { [scan [string range $comment $foundIndex end] "%f" score] == 1 } {
+			if { $score > 10 } { set score 9.9 }
+			if { $score < -10 } { set score -9.9 }
+		    }
+		}
+	    }
+	}
+	if { $score != -20.0 } {
+	    # we have found something valid, check if the score should be inverted
+	    if { $invw == 1 &&  $side == 1 } { set score [expr 0.0 - $score] }
+	    if { $invb == 1 &&  $side == 0 } { set score [expr 0.0 - $score] }
+	    lappend moveScores $movenr $score
+	}
+	set movenr [expr $movenr + 0.5]
+	if { $side == 0 } { set side 1 } else { set side 0 }
+    }
+    return $moveScores
+}
+
+proc ::tools::graphs::score::Refresh { {docreate 1 }} {
   set linecolor red
+  set firstColor darkgreen
+  set secondColor blue
   set linewidth 2
   set psize 2
   
   set w .sgraph
+  # Game has changed, but window is not open: do nothing
+  if {! [winfo exists $w] && $docreate == 0 } { return }
   
-  if {! [winfo exists $w]} {
-    toplevel $w
+  if {! [winfo exists $w] } {
+    ::createToplevel $w
     menu $w.menu
-    $w configure -menu $w.menu
+    ::setMenu $w $w.menu
     $w.menu add cascade -label GraphFile -menu $w.menu.file
     menu $w.menu.file
     $w.menu.file add command -label GraphFileColor \
@@ -383,57 +610,90 @@ proc ::tools::graphs::score::Refresh {} {
     $w.menu.file add separator
     $w.menu.file add command -label GraphFileClose -command "destroy $w"
     $w.menu add cascade -label GraphOptions -menu $w.menu.options
+    $w.menu add command -label Help -accelerator F1 -command {helpWindow Graphs Score}
     #Checkbuttons for Invert white/black Score in Score graph
     menu $w.menu.options
-    foreach i {White Black} {
+    foreach i {White Black Both ThinkTime TimeSum } {
       $w.menu.options add checkbutton -label GraphOptions$i \
           -variable ::tools::graphs::score::$i -offvalue "0" -onvalue "1" \
           -command "::tools::graphs::score::Refresh"
     }
-    
-    canvas $w.c -width 500 -height 300
+    canvas $w.c -width 500 -height 300 -selectforeground [ttk::style lookup . -foreground] -background [ttk::style lookup . -background]
+
     $w.c create text 25 5 -tag text -justify center -width 1 \
         -font font_Regular -anchor n
     pack $w.c -side top -expand yes -fill both
     bind $w <F1> {helpWindow Graphs Score}
     bind $w <Configure> {
-      .sgraph.c itemconfigure text -width [expr {[winfo width .sgraph.c] - 50}]
+      .sgraph.c itemconfigure text -width [expr {[winfo width .sgraph.c] - 20}]
       .sgraph.c coords text [expr {[winfo width .sgraph.c] / 2}] 10
-      ::utils::graph::configure score -height [expr {[winfo height .sgraph.c] - 90}]
-      ::utils::graph::configure score -width [expr {[winfo width .sgraph.c] - 100}]
+      ::utils::graph::configure score -height [expr {[winfo height .sgraph.c] - 50}]
+      ::utils::graph::configure score -width [expr {[winfo width .sgraph.c] - 40}]
       ::utils::graph::redraw score
     }
-    bind $w.c <$::MB3> ::tools::graphs::score::Refresh
     bind $w.c <1> {::tools::graphs::score::Move %x}
-    bind $w <Control-Z> ::tools::graphs::score::Refresh
     wm title $w "Scid: [tr ToolsScore]"
+    ::createToplevelFinalize $w
     ::tools::graphs::score::ConfigMenus
   }
-  
-  $w.c itemconfigure text -width [expr {[winfo width $w.c] - 50}]
+  ::setTitle $w "Scid: [tr ToolsScore]"
+
+  $w.c itemconfigure text -width [expr {[winfo width $w.c] - 20}]
   $w.c coords text [expr {[winfo width $w.c] / 2}] 10
-  set height [expr {[winfo height $w.c] - 90} ]
-  set width [expr {[winfo width $w.c] - 100} ]
-  ::utils::graph::create score -width $width -height $height -xtop 50 -ytop 45 \
-      -ytick 1 -xtick 5 -font font_Small -canvas $w.c -textcolor black \
-      -hline {{gray80 1 each 1} {black 1 at 0}} \
+  set height [expr {[winfo height $w.c] - 50} ]
+  set width [expr {[winfo width $w.c] - 40} ]
+  set yticks 1
+  if { $::tools::graphs::score::Both == 1 || $::tools::graphs::score::ThinkTime == 1} {
+      ::setTitle $w "Scid: [tr ToolsScore] & [tr Time]"
+      set max 0
+      # Find max Value of time, then set the tick value vor horizontal lines
+      foreach j { "w" "b"} {
+	  set coords [MoveTimeList $j $::tools::graphs::score::TimeSum]
+	  set coords$j $coords
+	  set ncoords [expr {[llength $coords] - 1}]
+	  for {set i 0} {$i < $ncoords} {incr i 2} {
+	      set y [lindex $coords [expr {$i + 1}]]
+	      if { $y > $max } { set max $y }
+	  }
+      }
+      if {$max > 20} { set yticks 5 }
+      if {$max > 50} { set yticks 10 }
+      if {$max > 100} { set yticks 20 }
+  }
+  if { $::tools::graphs::score::ThinkTime == 1 &&  $::tools::graphs::score::Both == 0 } {
+      ::setTitle $w "Scid: [tr Time]" }
+
+  ::utils::graph::create score -width $width -height $height -xtop 25 -ytop 25 \
+      -ytick $yticks -xtick 5 -font font_Small -canvas $w.c -textcolor black \
+      -hline [list [list gray80 1 each $yticks ]] \
       -vline {{gray80 1 each 1} {steelBlue 1 each 5}}
-  
+
   # Create fake dataset with bounds so we see at least -1.0 to 1.0:
-  ::utils::graph::data score bounds -points 0 -lines 0 -bars 0 -coords {1 -0.9 1 0.9}
+  ::utils::graph::data score bounds -points 0 -lines 0 -bars 0 -coords {1 0 1 0.9}
   
   # Update the graph:
   set whiteelo [sc_game tag get WhiteElo]
   set blackelo [sc_game tag get BlackElo]
   if {$whiteelo == 0} {set whiteelo ""} else {set whiteelo "($whiteelo)"}
   if {$blackelo == 0} {set blackelo ""} else {set blackelo "($blackelo)"}
-  $w.c itemconfigure text -text "[sc_game info white]$whiteelo - [sc_game info black]$blackelo\n[sc_game info site]  [sc_game info date]"
+  $w.c itemconfigure text -text "[sc_game info white]$whiteelo - [sc_game info black]$blackelo  [sc_game info site]  [sc_game info date]"
   busyCursor $w
   update
-  #Klimmek: Invert white/black Score in Score graph
-  catch {::utils::graph::data score data -color $linecolor -points 1 -lines 1 \
-        -linewidth $linewidth -radius $psize -outline $linecolor \
-        -coords [sc_game scores $::tools::graphs::score::White $::tools::graphs::score::Black]}
+
+  if { $::tools::graphs::score::Both || $::tools::graphs::score::ThinkTime } {
+      # draw move time
+      catch {::utils::graph::data score data1 -color $firstColor -points 0 -lines 1\
+		  -key [sc_game info white] -linewidth $linewidth -radius $psize -outline $firstColor -coords $coordsw }
+      catch {::utils::graph::data score data2 -color $secondColor -points 0 -lines 1 \
+		 -linewidth $linewidth -radius $psize -outline $secondColor -coords $coordsb}
+  }
+  if { $::tools::graphs::score::Both || $::tools::graphs::score::ThinkTime == 0 } {
+      # draw score bars
+      catch {::utils::graph::data score data -color $linecolor -points 0 -lines 0 -bars 2 \
+		 -linewidth $linewidth -radius $psize -outline $linecolor \
+		 -coords [MoveScoreList $::tools::graphs::score::White $::tools::graphs::score::Black]}
+  }
+
   ::utils::graph::redraw score
   unbusyCursor $w
   update
@@ -449,14 +709,18 @@ proc ::tools::graphs::score::ConfigMenus {{lang ""}} {
   foreach idx {0 1 3} tag {Color Grey Close} {
     configMenuText $m.file $idx GraphFile$tag $lang
   }
-  #Klimmek: translate optionsmenu
-  foreach idx {0 1} tag {White Black} {
+  foreach idx {0 1 2} tag {White Black Both} {
     configMenuText $m.options $idx GraphOptions$tag $lang
   }
+  #add option to show used Time and toggle between "Sum of time" (in min) and "Time per move" (in sec)
+  $m entryconfig 2 -label $::tr(Help)
+  $m.options entryconfig 3 -label $::tr(Time)
+  $m.options entryconfig 4 -label $::tr(Total)
+
 }
 
 proc ::tools::graphs::score::Move {xc} {
-  set x [expr {round([::utils::graph::xunmap score $xc] * 2)} ]
+  set x [expr {round([::utils::graph::xunmap score $xc] * 2 + 0.5)} ]
   sc_move start
   sc_move forward $x
   updateBoard
@@ -468,8 +732,21 @@ proc ::tools::graphs::score::Move {xc} {
 
 set ::tools::graphs::rating::year 1900
 set ::tools::graphs::rating::type both
+set ::tools::graphs::rating::elo info
 set ::tools::graphs::rating::player ""
 
+proc ::tools::graphs::rating::GetElo { player } {
+  if {$::tools::graphs::rating::elo == "elo"} {
+    set eloList [sc_name elo  $::tools::graphs::rating::year $player]
+  } else {
+    set filter [sc_filter new $::curr_db]
+    sc_filter search $::curr_db $filter header -date "$::tools::graphs::rating::year 2047"
+    set eloList [sc_base player_elo $::curr_db $filter $player]
+    sc_filter release $::curr_db $filter
+  }
+  return $eloList
+}
+
 proc ::tools::graphs::rating::Refresh {{type ""} {player ""}} {
   set white [sc_game info white]
   set black [sc_game info black]
@@ -488,7 +765,7 @@ proc ::tools::graphs::rating::Refresh {{type ""} {player ""}} {
   if {! [winfo exists $w]} {
     toplevel $w
     menu $w.menu
-    $w configure -menu $w.menu
+    ::setMenu $w $w.menu
     $w.menu add cascade -label GraphFile -menu $w.menu.file
     menu $w.menu.file
     $w.menu.file add command -label GraphFileColor \
@@ -505,13 +782,19 @@ proc ::tools::graphs::rating::Refresh {{type ""} {player ""}} {
           -command "::tools::graphs::rating::Refresh"
     }
     $w.menu.options add separator
+    foreach i { EloDB EloFile } j {info elo} {
+      $w.menu.options add radiobutton -label GraphOptions$i \
+        -variable ::tools::graphs::rating::elo -value $j \
+        -command "::tools::graphs::rating::Refresh"
+    }
+    $w.menu.options add separator
     foreach i {1900 1980 1985 1990 1995 2000 2005 2010 2015 } {
       $w.menu.options add radiobutton -label "Since $i" \
           -variable ::tools::graphs::rating::year -value $i \
           -command "::tools::graphs::rating::Refresh"
     }
     
-    canvas $w.c -width 500 -height 300
+    canvas $w.c -width 500 -height 300 -selectforeground [ttk::style lookup . -foreground] -background [ttk::style lookup . -background]
     $w.c create text 25 10 -tag text -justify center -width 1 \
         -font font_Regular -anchor n
     pack $w.c -side top -expand yes -fill both
@@ -543,12 +826,11 @@ proc ::tools::graphs::rating::Refresh {{type ""} {player ""}} {
   update
   
   set title "[tr ToolsRating]: "
-  set year $::tools::graphs::rating::year
   if {$type == "player"} {
     append title $player
     catch {::utils::graph::data ratings d -color $whiteColor -points 1 -lines 1 \
           -linewidth $lwidth -radius $psize -outline $whiteColor \
-          -coords [sc_name info -ratings:$year $player]}
+          -coords [GetElo $player] }
   }
   if {$type == "white"  ||  $type == "both"} {
     set key ""
@@ -556,7 +838,7 @@ proc ::tools::graphs::rating::Refresh {{type ""} {player ""}} {
     append title $white
     catch {::utils::graph::data ratings d -color $whiteColor -points 1 -lines 1 \
           -linewidth $lwidth -radius $psize -outline $whiteColor \
-          -key $key -coords [sc_name info -ratings:$year $white]}
+          -key $key -coords [GetElo $white] }
   }
   if {$type == "both"} { append title " - " }
   if {$type == "black"  ||  $type == "both"} {
@@ -565,7 +847,7 @@ proc ::tools::graphs::rating::Refresh {{type ""} {player ""}} {
     append title $black
     catch {::utils::graph::data ratings d2 -color $blackColor -points 1 -lines 1 \
           -linewidth $lwidth -radius $psize -outline $blackColor \
-          -key $key -coords [sc_name info -ratings:$year $black]}
+          -key $key -coords [GetElo $black]}
   }
   set minYear [expr {int([::utils::graph::cget ratings axmin])} ]
   set maxYear [expr {int([::utils::graph::cget ratings axmax])} ]
@@ -586,7 +868,7 @@ proc ::tools::graphs::rating::ConfigMenus {{lang ""}} {
   foreach idx {0 1 3} tag {Color Grey Close} {
     configMenuText $m.file $idx GraphFile$tag $lang
   }
-  foreach idx {0 1 2 3} tag {White Black Both PInfo} {
+  foreach idx {0 1 2 3 5 6} tag {White Black Both PInfo EloDB EloFile} {
     configMenuText $m.options $idx GraphOptions$tag $lang
   }
 }
@@ -609,9 +891,9 @@ proc tools::graphs::absfilter::Open {} {
     set absfilterGraph 0
     return
   }
-  toplevel $w
+  win::createDialog $w 0
   menu $w.menu
-  $w configure -menu $w.menu
+  ::setMenu $w $w.menu
   $w.menu add cascade -label GraphFile -menu $w.menu.file
   configMenuText $w.menu 0 GraphFile $::language
   menu $w.menu.file
@@ -626,13 +908,11 @@ proc tools::graphs::absfilter::Open {} {
   set absfilterGraph 1
   bind $w <Destroy> {set absfilterGraph 0}
   
-  frame $w.b
-  pack $w.b -side bottom -fill x
-  label $w.b.status -width 1 -font font_Small -anchor w
-  frame $w.sep -height 2 -borderwidth 2 -relief sunken -background white
-  pack $w.sep -side bottom -fill x -pady 4
+  ttk::frame $w.b
+  pack $w.b -side top -fill x
+  ttk::label $w.b.status -width 1 -font font_Small -anchor w
   
-  canvas $w.c -width 600 -height 400
+  canvas $w.c -width 600 -height 400 -selectforeground [ttk::style lookup . -foreground] -background [ttk::style lookup . -background]
   $w.c create text 25 5 -tag title -justify center -width 1 \
       -font font_Small -anchor n
   $w.c create text 250 295 -tag type -justify center -width 1 \
@@ -654,15 +934,14 @@ proc tools::graphs::absfilter::Open {} {
   bind $w.c <1> tools::graphs::absfilter::Switch
   bind $w.c <$::MB3> ::tools::graphs::absfilter::Refresh
   foreach {name text} {decade Decade year Year elo Rating move moves} {
-    radiobutton $w.b.$name -padx 4 -pady 3 -text $::tr($text) \
+    ttk::radiobutton $w.b.$name -text $::tr($text) \
         -variable ::tools::graphs::absfilter::type -value $name \
         -command ::tools::graphs::absfilter::Refresh
     pack $w.b.$name -side left -padx 1 -pady 2
   }
-  button $w.b.setup -image tb_graph -command configureFilterGraph
-  dialogbutton $w.b.close -text $::tr(Close) -command "destroy $w"
+  ttk::button $w.b.setup -image tb_config -command configureFilterGraph
   pack $w.b.decade $w.b.elo -side left -padx 1 -pady 2
-  pack $w.b.close $w.b.setup -side right -padx 2 -pady 2
+  pack $w.b.setup -side right -pady 2
   pack $w.b.status -side left -padx 2 -pady 2 -fill x -expand yes
   
   ::tools::graphs::absfilter::Refresh
@@ -835,4 +1114,4 @@ proc ::tools::graphs::absfilter::Refresh {} {
   unbusyCursor .
   update
 }
-### End of file: graph.tcl
+### End of file: graphs.tcl
